#include <cstdio>

#include <cuda_runtime.h>
#include <device_functions.h>
#include <device_launch_parameters.h>

__global__ void tableKernel(float *devPtr, float step){
  int index=blockIdx.x*blockDim.x + threadIdx.x;
  float x=step*index;
  devPtr[index]=__sinf(sqrtf(x));
}

void buildTable(float *res, int n, float step){
  float *devPtr;
  cudaMalloc(&devPtr, n*sizeof(float));
  tableKernel<<<dim3(n/256),dim3(256)>>>(devPtr,step);
  cudaMemcpy(res,devPtr,n*sizeof(float),cudaMemcpyDeviceToHost);
  cudaFree(devPtr);
}

int main(){
	int n = 1e6;
	float step = 0.001f;
	float *res = new float[n];

	buildTable(res, n, step);

	delete[] res;

	puts("Все");
	return 0;
}
